# Unq

A rate limiter and function executing timing library that allows receiving results from the executed functions using futures.

Use a `RateLimiter` class instance to submit functions to be executed. All objects and methods are documented in the code.

The library supports `mypy` static typing.